powered by
How to get the dataset can be viewed in code under data-raw. Cases in case_id column can be directly mapped to a GDC portal page, e.g. https://portal.gdc.cancer.gov/cases/30a1fe5e-5b12-472c-aa86-c2db8167ab23.
data-raw
case_id
A data frame with 150849 rows and 5 variables.
# \donttest{ load_data("tcga") # }
Run the code above in your browser using DataLab